pitchtools.transpose_pitch_expr_into_pitch_range
================================================

.. autofunction:: abjad.tools.pitchtools.transpose_pitch_expr_into_pitch_range.transpose_pitch_expr_into_pitch_range
